#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
# @File    : util_check.py
# @Time    : 2021-07-23
# @Author  : Skypekey


"""Some checks on files or directories."""
import os
import re
from typing import Dict, List, Tuple, Union
from pathlib import Path
import threading
import socket


def is_exist(file_path: Union[str, Path], create: bool = False) -> bool:
    """Test whether file_path exists.

    :param file_path(str): The path that needs to be judged.\n
    :param create(bool): Whether to create. If create is True,\n
            create a directory named file_path if it does not exist.\n
    :return(bool): A boolean representing whether file_path exists."""

    if create and not os.path.exists(file_path):
        os.makedirs(file_path)
    return os.path.exists(file_path)


def is_not_null(file_path: Union[str, Path]) -> bool:
    """Test whether file_path is not null.

    :param file_path(str): The path that needs to be judged.\n
    :return(bool): Returns whether file_path is not null.\n
        Return True if file_path exist and not null.\n
        Return False, it may be the following:\n
            file_path not file or dir; file_path not exist."""

    result = False
    if is_exist(file_path):
        if file_or_dir(file_path) == "file":
            result = os.path.getsize(file_path) != 0
        elif file_or_dir(file_path) == "dir":
            result = bool(os.listdir(file_path))
    return result


def file_or_dir(file_path: Union[str, Path]) -> str:
    """ Returns file type of the file_path.

    :param file_path(str): The path that needs to be judged.\n
    :return(str): Returns file type of the file_path.\n
        The return values are as follows.\n
            "dir": If file_path is a directory,\n
            "file": If file_path is a file,\n
            file_path + "Not exist!": If file_path is not exist\n
            "Not file or dir!": If file_path not a dir or file."""

    result = ""
    if not is_exist(file_path):
        result = str(file_path) + "Not exist!"
    elif os.path.isdir(file_path):
        result = "dir"
    elif os.path.isfile(file_path):
        result = "file"
    else:
        result = "Not file or dir!"
    return result


def check_ip(ip: str) -> bool:
    """Test whether the IP is valid.

    :param ip(str): The IP that needs to be judged.\n
    :return(bool): Returns whether url is valid.\n
        Return False, if the IP is not legal."""

    ip_rex = r'(?=(\b|\D))(((\d{1,2})|(1\d{1,2})|(2[0-4]\d)|(25[0-5]))\.)' + \
        r'{3}((\d{1,2})|(1\d{1,2})|(2[0-4]\d)|(25[0-5]))(?=(\b|\D))'

    is_legal = re.match(re.compile(ip_rex), ip)
    if is_legal:
        return True
    else:
        return False


def check_url(url: str, style: str = "http") -> bool:
    """Test whether url is valid.

    :params url(str): The url that needs to be judged.\n
    :return(bool): Returns whether url is valid.\n
        Return False, if the style is not web or git.
    """

    result = False
    if style == "http":
        result = True if re.match(r'^https?:/{2}\w.+$', url) else False
    elif style == "git":
        result = True if re.match(
            r'^(http(s)?:\/\/([^\/]+?\/){2}|git@[^:]+:[^\/]+?\/).*?.git$', url
        ) else False
    return result


def check_arg(info_dict: Dict, required_list: List, empty_arg: List,
              optional_list: List, method="") -> Tuple:
    """Check whether the parameters are correct.

    :param info_dict(Dict): Information about whether the parameter
                            being checked is correct.
    :param required_list(List): List of required parameters.
    :param optional_list(List): List of Optional parameters.
    :param empty_arg(List): List of nullable parameters.
    :param method(str): Method of checking parameters.
        one: Info_dict must contains at least one parameter from optional_list.

    :return Tuple(bool, Any): If there is no error, return (True, ""),
        otherwise False and an error message is returned."""

    flag = False

    # Check if parameter in info_dict not exists
    # in required_list, optional_list and empty_arg.
    not_exist = []
    for i in info_dict.keys():
        if i not in required_list and i not in optional_list and\
                i not in empty_arg:
            not_exist.append(i)
            flag = True
    if flag:
        return (False, "Please confirm whether the following parameters\
                        are correct: " + ",".join(not_exist))

    # Check if parameter in required_list not exists in info_dict.
    for _ in required_list:
        if _ not in info_dict:
            return (False, f"{' '.join(required_list)} \
                             are all required parameter")

    # Check if parameter in required_list is not null.
    for k, v in info_dict.items():
        if not v and k not in empty_arg:
            return (False, f"The parameter {k}'value cannot be empty")

    flag = True
    if method == "one":
        for _ in optional_list:
            if _ in info_dict:
                flag = False
        if flag:
            return (False, f"Info_dict must contains at least one parameter\
                             from optional_list")

    # Check if the format of parameter in info_dict is correct.
    return (True, "")


def check_port(IP, Port, protocol="tcp", timeout=1):
    """Check whether the Port on IP is open.

    :param IP(str): The IP that needs to be checked.\n
    :param Port(int): The Port on IP that needs to be checked.\n
    :param timeout(int): Timeout period.

    :return Tuple(bool, Any): If there is no error, return (True, ""),
        otherwise False and an error message is returned."""

    threadlock = threading.Lock()
    flag = False
    result = ""
    socket.setdefaulttimeout(timeout)
    try:
        if protocol.lower() == "tcp":
            conn = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        elif protocol.lower() == "udp":
            conn = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
        else:
            return (False, "The protocol only can be TCP or UDP")
        conn.connect((IP, Port))
        threadlock.acquire()
        flag = True
    except Exception as e:
        threadlock.acquire()
        result = str(e)
    finally:
        threadlock.release()
        conn.close()
        return (flag, result)


if __name__ == "__main__":
    pass



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
# @File    : util_hashlib.py
# @Time    : 2021-07-23
# @Author  : Skypekey


"""Some functions related to hash operations."""
import hashlib
import hmac
from pathlib import Path
from typing import Union
from common import util_check


def get_str_md5(string: str) -> str:
    """Returns the MD5 value of a string.

    :param string(str): String to get the MD5 value.\n
    :return(str): The MD5 value of string.\n
        If string is empty, the MD5 value is empty."""

    md5name = ""
    if not string:
        tmp_md5 = hashlib.md5(bytes(string, encoding="UTF-8"))
        md5name = tmp_md5.hexdigest().upper()
    return md5name


def get_file_md5(file_path: Union[str, Path]) -> str:
    """Returns the MD5 value of a file.

    :param file_path(str): File path to get MD5 value.\n
    :return(str): the MD5 value of file_path.\n
        If the MD5 value is empty, it may be the following:\n
            file_path not file; file_path not exist; file_path is null."""

    md5name = ""
    expr1 = util_check.is_not_null(file_path)
    expr2 = util_check.file_or_dir(file_path) == "file"
    if expr1 and expr2:
        with open(file_path, "rb") as f:
            tmp_md5 = hashlib.md5()
            while True:
                tmp_file = f.read(8096)
                if not tmp_file:
                    break
                tmp_md5.update(tmp_file)
            md5name = tmp_md5.hexdigest().upper()
    return md5name


def transform_str(tmp_str, key, length):
    """Returns the transformed str of a tmp_str.

    :param tmp_str(str): The str will be transformed.\n
    :param key(str): The str which used to transform tmp_str.\n
    :param length(int): The length of transformed str.\n
    :return(str): The transformed str of a tmp_str"""
    tmp_str = tmp_str.encode(encoding="utf-8")
    key = key.encode(encoding="utf-8")

    hmd5 = hmac.new(key, tmp_str, hashlib.sha256).hexdigest().encode(
        encoding="utf-8")
    rule = list(hmac.new("img".encode(encoding="utf-8"),
                         hmd5, hashlib.sha256).hexdigest())
    source = list(hmac.new("tupian".encode(encoding="utf-8"),
                           hmd5, hashlib.sha256).hexdigest())

    for i in range(0, 32):
        if not(source[i].isdigit()):
            if rule[i] in "ThisFuctionsisImg20210310":
                source[i] = source[i].upper()

    code = "".join(source[1:length])
    for i in source:
        if not(i.isdigit()):
            code = i + code
            break
    return code


if __name__ == "__main__":
    pass



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
# @File    : util_json.py
# @Time    : 2021-07-23
# @Author  : Skypekey


"""Some functions related to json file operations."""
import json
from typing import Any, Dict, Union
from pathlib import Path
from common import util_check


def read_json(json_file: Union[str, Path]) -> Dict[Any, Any]:
    """Return the contents of json_file.

    :param json_file(str): Json file to be read.\n
    :return(dict): the contents of json_file.\n
        If the return value is empty, it may be the following:\n
            json_file not file; json_file not exist; json_file is null."""

    json_dict = {}
    expr1 = util_check.is_not_null(json_file)
    expr2 = util_check.file_or_dir(json_file) == "file"
    if expr1 and expr2:
        with open(json_file, "r", encoding="UTF-8") as f:
            json_dict = json.load(f)
    return json_dict


def write_json(json_file: Union[str, Path], json_dict: Dict[Any, Any],
               mode: str = "w") -> None:
    """Write the contents of json_dict to json_file.

    :param json_file(str): Json file to be written.\n
    :param json_dict(str): What will be written to the json file.\n
    :param mode(str): How to write json file, default is "w".\n
        Character Meaning\n
            'w'   open for writing, create if not exists.
                  truncating the file first.\n
            'x'   create a new file and open it for writing.\n
            'a'   open for writing, create if not exists.
                  appending to the end of the file.\n
            'b'   binary mode.
                  If you use this, no encoding parameter is required\n
            't'   text mode (default)\n
            '+'   open a disk file for updating (reading and writing)\n
    :return(None): No return value."""

    with open(json_file, mode, encoding="UTF-8") as f:
        # ensure_ascii = False is to display Chinese,
        # if not written, it will be displayed as unicode encoding.
        # indent is to format the json file,
        # otherwise it will be displayed on one line.
        json.dump(json_dict, f, ensure_ascii=False, indent=4)


if __name__ == "__main__":
    pass



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
# @File    : util_random.py
# @Time    : 2021-07-23
# @Author  : Skypekey


"""Custom random function."""
import random


def random_str(string: str) -> str:
    """Randomly shuffle strings."""
    list_str = list(string)
    random.shuffle(list_str)
    return "".join(list_str)


if __name__ == "__main__":
    pass



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
# @File    : __init__.py
# @Time    : 2021-12-16
# @Author  : Skypekey


from common import *
from exception import *
from file import *
from db import *


if __name__ == "__main__":
    pass



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
# @File    : util_str.py
# @Time    : 2021-07-23
# @Author  : Skypekey


"""Custom str function."""


def format_str(string: str) -> str:
    r"""Remove all kinds of blanks in the string,
       including full-width blanks and non-breaking blanks.

       The list is \r\n, \t, \r, \n, \xa0, \u3000, &nbsp;, [space]"""
    string = string.replace("\r\n", "")
    string = string.replace("\t", "")
    string = string.replace("\r", "")
    string = string.replace("\n", "")
    string = string.replace("\xa0", "")
    string = string.replace("\u3000", "")
    string = string.replace("&nbsp;", "")
    string = string.strip()
    return string


if __name__ == "__main__":
    pass



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
# @File    : util_time.py
# @Time    : 2021-07-23
# @Author  : Skypekey


"""Some functions related to time operations."""
import time

NOW_TIME = time.time()


def format_time(timestamp: float = NOW_TIME,
                format_str: str = '%Y-%m-%d %H:%M:%S') -> str:
    """Format timestamp returns format_str time.

    :param timestamp(float): The timestamp to be formatted.\n
        Defaults is the current timestamp.\n
    :param format_str(str): Time format used to format time.\n
        Default is '%Y-%m-%d %H:%M:%S'.\n
        Commonly used format codes:\n
            %Y: Year with century as a decimal number.\n
            %m: Month as a decimal number [01,12].\n
            %d: Day of the month as a decimal number [01,31].\n
            %H: Hour (24-hour clock) as a decimal number [00,23].\n
            %M: Minute as a decimal number [00,59].\n
            %S: Second as a decimal number [00,61].\n
            %z: Time zone offset from UTC.\n
            %a: Locale's abbreviated weekday name.\n
            %A: Locale's full weekday name.\n
            %b: Locale's abbreviated month name.\n
            %B: Locale's full month name.\n
            %c: Locale's appropriate date and time representation.\n
            %I: Hour (12-hour clock) as a decimal number [01,12].\n
            %p: Locale's equivalent of either AM or PM.\n
    :return(str): Formatted time string."""

    tmp_time = time.localtime(timestamp)
    return time.strftime(format_str, tmp_time)


if __name__ == "__main__":
    pass



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
# @File    : util_file.py
# @Time    : 2021-07-23
# @Author  : Skypekey


"""Some functions related to file operations."""
import os
from pathlib import Path
from typing import Any, Union
from common import util_time, util_check

SIZE_UNIT = {
    "GB": float(1024*1024*1024),
    "MB": float(1024*1024),
    "KB": float(1024)
}


def write_file(file_path: Union[str, Path],
               msg: str, mode: str = "a", encoding: str = "UTF-8") -> None:
    """Write the contents of msg to file_path.

    :param file_path(str): File to be written.\n
    :param msg(str): What will be written to the file_path.\n
    :param mode(str): How to write file, default is "a".\n
        Character Meaning\n
            'w'   open for writing, create if not exists.
                  truncating the file first.\n
            'x'   create a new file and open it for writing\n
            'a'   open for writing, create if not exists.
                  appending to the end of the file (default).\n
            'b'   binary mode.
                  If you use this, no encoding parameter is required\n
            't'   text mode (default).
            '+'   open a disk file for updating (reading and writing)\n
    :param encoding(str): Encoding format to write file, default is "UTF-8".\n
    :return(None): No return value."""

    if "b" not in mode:
        with open(file_path, mode, encoding=encoding) as f:
            f.write(msg)
    else:
        with open(file_path, mode) as f:
            f.write(msg)


def read_file(file_path: Union[str, Path], need_list: bool = False,
              mode: str = "r", encoding: str = "UTF-8") -> Any:
    """Return the content of file_path.

    :param file_path(str): File to be read.\n
    :param mode(str): How to read file, default is "r".\n
        Character Meaning\n
            'r'   open for reading (default).\n
            'b'   binary mode.
                  If you use this, no encoding parameter is required\n
            't'   text mode (default).\n
    :param encoding(str): Encoding format to read file, default is "UTF-8".\n
    :return(str): The contents of file_path.\n
        If the contents of file_path is empty, it may be the following:\n
            file_path not file; file_path not exist; file_path is null."""

    msg = ""
    expr1 = util_check.is_not_null(file_path)
    expr2 = util_check.file_or_dir(file_path) == "file"
    if expr1 and expr2:
        if "b" not in mode:
            with open(file_path, mode, encoding=encoding) as f:
                if need_list:
                    msg = []
                    lines = f.readlines()
                    for line in lines:
                        msg.append(line.strip())
                else:
                    msg = f.read()
        else:
            with open(file_path, mode) as f:
                msg = f.read()
    return msg


def get_file_suffix(filename: str) -> str:
    """Return the suffix of filename.

    :param filename(str): File name to get the suffix.\n
    :return(str): The suffix of filename."""

    return Path(filename).suffix


def get_file_size(file_path: Union[str, Path],
                  size_unit: str = "MB") -> float:
    """Return the size of file_path.

    :param file_path(str): File path to get file size.\n
    :param size_unit(str): File size unit. Default is 'MB'.\n
        Character Meaning\n
        'GB': The file's byte size will be divided by 1024*1024*1024\n
        'MB': The file's byte size will be divided by 1024*1024\n
        'KB': The file's byte size will be divided by 1024\n
    :return(float): The size of file_path.\n
        Exact to two digits after the decimal point.\n
        A file size of -1 means the file does not exist."""

    size_type = 0.0
    if size_unit in SIZE_UNIT:
        size_type = SIZE_UNIT[size_unit]
    else:
        size_type = SIZE_UNIT["MB"]
    file_size = -1.0
    if util_check.is_exist(file_path):
        tmp_size = os.path.getsize(file_path)
        size = tmp_size / size_type
        file_size = round(size, 2)
    return file_size


def get_file_ctime(file_path: Union[str, Path],
                   format_str: str = '%Y-%m-%d %H:%M:%S') -> str:
    """Get and format file creation time and return.

    :param file_path(str): File path to get creation time.\n
    :param format_str(str): Time format used to format time.\n
        Default is '%Y-%m-%d %H:%M:%S'\n
        Commonly used format codes:\n
            %Y: Year with century as a decimal number.\n
            %m: Month as a decimal number [01,12].\n
            %d: Day of the month as a decimal number [01,31].\n
            %H: Hour (24-hour clock) as a decimal number [00,23].\n
            %M: Minute as a decimal number [00,59].\n
            %S: Second as a decimal number [00,61].\n
            %z: Time zone offset from UTC.\n
            %a: Locale's abbreviated weekday name.\n
            %A: Locale's full weekday name.\n
            %b: Locale's abbreviated month name.\n
            %B: Locale's full month name.\n
            %c: Locale's appropriate date and time representation.\n
            %I: Hour (12-hour clock) as a decimal number [01,12].\n
            %p: Locale's equivalent of either AM or PM.\n
    :return(str): A formatted time string of file_path creation time.\n
        If the creation time is an empty string, the file does not exist."""

    ctime = ""
    if util_check.is_exist(file_path):
        tmp_time = os.path.getctime(file_path)
        ctime = util_time.format_time(tmp_time, format_str)
    return ctime


def get_file_atime(file_path: Union[str, Path],
                   format_str: str = '%Y-%m-%d %H:%M:%S') -> str:
    """Get and format file access time and return.

    :param file_path(str): File path to get access time.\n
    :param format_str(str): Time format used to format time.\n
        Default is '%Y-%m-%d %H:%M:%S'\n
        Commonly used format codes:\n
            %Y: Year with century as a decimal number.\n
            %m: Month as a decimal number [01,12].\n
            %d: Day of the month as a decimal number [01,31].\n
            %H: Hour (24-hour clock) as a decimal number [00,23].\n
            %M: Minute as a decimal number [00,59].\n
            %S: Second as a decimal number [00,61].\n
            %z: Time zone offset from UTC.\n
            %a: Locale's abbreviated weekday name.\n
            %A: Locale's full weekday name.\n
            %b: Locale's abbreviated month name.\n
            %B: Locale's full month name.\n
            %c: Locale's appropriate date and time representation.\n
            %I: Hour (12-hour clock) as a decimal number [01,12].\n
            %p: Locale's equivalent of either AM or PM.\n
    :return(str): A formatted time string of file_path access time.\n
        If the access time is an empty string, the file does not exist."""

    atime = ""
    if util_check.is_exist(file_path):
        tmp_time = os.path.getatime(file_path)
        atime = util_time.format_time(tmp_time, format_str)
    return atime


def get_file_mtime(file_path: Union[str, Path],
                   format_str: str = '%Y-%m-%d %H:%M:%S') -> str:
    """Get and format file modification time and return.

    :param file_path(str): File path to get modification time.\n
    :param format_str(str): Time format used to format time.\n
        Default is '%Y-%m-%d %H:%M:%S'.\n
        Commonly used format codes:\n
            %Y: Year with century as a decimal number.\n
            %m: Month as a decimal number [01,12].\n
            %d: Day of the month as a decimal number [01,31].\n
            %H: Hour (24-hour clock) as a decimal number [00,23].\n
            %M: Minute as a decimal number [00,59].\n
            %S: Second as a decimal number [00,61].\n
            %z: Time zone offset from UTC.\n
            %a: Locale's abbreviated weekday name.\n
            %A: Locale's full weekday name.\n
            %b: Locale's abbreviated month name.\n
            %B: Locale's full month name.\n
            %c: Locale's appropriate date and time representation.\n
            %I: Hour (12-hour clock) as a decimal number [01,12].\n
            %p: Locale's equivalent of either AM or PM.\n
    :return(str): A formatted time string of file_path modification time.\n
        If the modification time is an empty string,\n
        the file does not exist."""

    mtime = ""
    if util_check.is_exist(file_path):
        tmp_time = os.path.getmtime(file_path)
        mtime = util_time.format_time(tmp_time, format_str)
    return mtime


if __name__ == "__main__":
    pass



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
# @File    : util_mysql.py
# @Time    : 2021-12-14
# @Author  : Skypekey


#!/usr/bin/env python3
# -*- coding: UTF-8 -*-

"""A custom object for MySQL, to operate the MySQL database."""

import pymysql
from common import util_method
from exception import util_exception


class User_MySQL():
    def __init__(self, info, method="host") -> None:
        self.info = info
        self.method = method

    def __verify(self):
        """Initialize database authentication information.

        :param method(str): Method used for database authentication. Only host and socket.
        :param info(Dict): Database authentication information.\n
            The format of info:\n
                info = {
                    # required, where use host to access database.
                    "host": "host",
                    "username": "user", # required
                    "password": "password", # required
                    "port": 3306, # optional, default is 3306
                    "database": "mysql", # optional
                    # required, where use socket to access database.
                    "socket": "/tmp/mysql.sock"
                }
        :return Tuple(bool, db_conn|str, db_cur|None): If there is no error, return the database connection handle and cursor handle, otherwise an error message is returned."""

        arg_list = ["host", "username", "password",
                    "port", "database", "socket"]
        connect_info = self.info.copy()
        err_info = ""

        for i in self.info.keys():
            if i not in arg_list:
                err_info = f"非法参数 {i}，只允许以下参数：\n{''.join(arg_list)}"
                break
        if self.method not in ["host", "socket"]:
            err_info = "method 只能为 host 或 socket"
            # err_info = "Only host and socket methods are allowed"
        elif not isinstance(self.info, dict):
            err_info = "info 必须为字典对象"
        elif "username" not in self.info or not self.info["username"]:
            err_info = "info 中必须包含 username 且不能为空"
        elif "password" not in self.info or not self.info["password"]:
            err_info = "info 中必须包含 password 且不能为空"
        elif "database" not in self.info or not self.info["database"]:
            err_info = "info 中必须包含 database 且不能为空"
        elif self.method == "host":
            if "host" not in self.info or not self.info["host"]:
                err_info = f"When using {self.method} authentication,\
                             host is required"
            elif "port" not in self.info or not self.info["port"]:
                connect_info["port"] = 3306
        elif self.method == "socket":
            if "socket" not in self.info or not self.info["socket"]:
                err_info = f"When using {self.method} authentication,\
                             socket is required"

        util_method.return_info(err_info, connect_info)

    def __connect(self):
        """Connect to database."""

        try:
            flag, result = self.__verify()
            if flag:
                self.db_conn = pymysql.connect(**result)
                self.db_cur = self.db_conn.cursor(pymysql.cursors.DictCursor)
            else:
                raise util_exception.ParameterException(result)
        except Exception as e:
            return f"Database connection error, exception info is:\n{str(e)}"

    def __close(self):
        self.db_cur.close()
        self.db_conn.close()

    def __check(self, isquery=True):
        err_info = self.__connect()
        if not err_info:
            isselect = self.sql.lower().startswith("select")
            into = "into" in self.sql.lower().spilt(" ")
            if isquery and (not isselect or into):
                err_info = "Only Select sql statement is supported when use query method."
            elif not isquery and isselect and not into:
                err_info = "Sql statement must contains into when use noquery method and use select sql statement."

        util_method.return_info(err_info, "")

    def Query(self, sql):
        """Query data from the database.

        :param sql(str): It's a sql statement."""

        err_info = ""
        data = ""

        check_result = self.__check()
        if not check_result:
            try:
                self.db_cur.execute(sql)
                data = self.db_cur.fetchall()
            except Exception as e:
                err_info = f"sql statement is {sql}.\n exception info is:\n{str(e)}"
            finally:
                self.__close()
        util_method.return_info(err_info, data)

    def NoQuery(self, sql):
        """Change the data in the database.

        :param sql(str): It's a sql statement."""

        err_info = ""
        data = ""

        check_result = self.__check()
        if not check_result:
            try:
                self.db_cur.execute(sql)
                self.db_conn.commit()
            except Exception as e:
                self.db_conn.rollback()
                err_info = f"sql statement is {sql}.\n exception info is:\n{str(e)}"
            finally:
                self.__close()

        util_method.return_info(err_info, data)


if __name__ == "__main__":
    pass



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
# @File    : util_method.py
# @Time    : 2021-12-16
# @Author  : Skypekey


def return_info(err_info, data):

    if err_info:
        return (False, err_info)
    else:
        return (True, data)


if __name__ == "__main__":
    pass



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-

import setuptools
import os

here = os.path.abspath(os.path.dirname(__file__))

readme_file = os.path.join(here, 'README.md')
if os.path.exists(readme_file):
    with open(readme_file, encoding='UTF-8') as f:
        long_description = f.read()
else:
    long_description = "Some commonly used modules for personal use."

require_file = os.path.join(here, "requirements.txt")
if os.path.exists(require_file):
    with open(require_file, encoding='UTF-8') as f:
        install_requires = f.read().split("\n")
else:
    install_requires = []

setuptools.setup(
    name='user_tools',
    version='1.0.0',
    description='Some commonly used modules for personal use.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='SkypeKey',
    author_email='enablekey@outlook.com',
    url='https://github.com/Skypekey/user_tools',
    project_urls={
        'Documentation': 'https://github.com/Skypekey/user_tools/wiki',
        # 'Funding': 'https://donate.pypi.org',
        # 'Say Thanks!': 'http://saythanks.io/to/example',
        'Source': 'https://github.com/Skypekey/user_tools',
        'Tracker': 'https://github.com/Skypekey/user_tools/issues',
    },
    license='GNU GPLv3',
    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)',
        'Programming Language :: Python :: 3',
    ],
    keywords='time file json',
    packages=setuptools.find_packages(),
    install_requires=install_requires,
    python_requires='>=3.8',

    # If some data files are used in the module, and file in module directory.
    # the following options should be used.
    # package_data={
    #     'package_name': ['package_data.dat'],
    # },
    # If some data files are used in the module,
    # the file not in module directory.
    # the following options should be used.
    # data_files=[('data_directory', ['data/data_file'])],

    # If using MANIFEST.in files to find data files.
    # you must use the following options.
    # include_package_data=True,

    # If your package has a main function,
    # which must be executed from the specified module,
    # you must use the following options.
    # entry_points={
    #     'console_scripts': [
    #         'sample=sample:main',
    #     ],
    # },

    # The following are optional parameters,
    # generally do not need to be used.
    # py_modules=[],
    # scripts=['scripts/xmlproc_parse', 'scripts/xmlproc_val'],
)



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
# @File    : util_log.py
# @Time    : 2021-06-10
# @Author  : Skypekey


import pathlib
import logging
from functools import wraps
from logging.handlers import RotatingFileHandler


class Pylog():

    def __init__(self, log_file) -> None:

        self.log_file = log_file
        pathlib.Path(self.log_file).parent.mkdir(parents=True,
                                                 exist_ok=True)
        self.logger = logging.getLogger()  # 实例化一个logger对象
        self.logger.setLevel(logging.INFO)  # 设置初始显示级别
        self.fmt = logging.Formatter('%(asctime)s [%(levelname)s] %(message)s',
                                     datefmt='%Y-%m-%d %H:%M:%S')

    def __console(self, message, maxBytes=1024 * 1024 * 5, level=''):
        # 创建一个文件句柄
        file_handle = RotatingFileHandler(filename=self.log_file,
                                          mode='a', encoding="UTF-8",
                                          backupCount=1,
                                          maxBytes=maxBytes)
        # 创建一个输出格式
        file_handle.setFormatter(self.fmt)  # 文件句柄设置格式
        if(level.lower() == "debug"):
            file_handle.setLevel(logging.DEBUG)
        else:
            file_handle.setLevel(logging.INFO)
        self.logger.addHandler(file_handle)  # logger对象绑定文件句柄

        if level == 'info':
            self.logger.info(message)
        elif level == 'debug':
            self.logger.debug(message)
        elif level == 'warning' or level == 'warn':
            self.logger.warn(message)
        elif level == 'error':
            self.logger.error(message)
        elif level == 'fatal' or level == 'critical':
            self.logger.critical(message)
        self.logger.removeHandler(file_handle)
        file_handle.close()

    def logger_tuple(self, func):
        """用于返回值为(True/False, "输出")的函数打印日志。"""

        @wraps(func)
        def with_logging(*args, **kwargs):
            result = func(*args, **kwargs)
            print(result)
            if result[0]:
                self.__console(result[1])
            else:
                self.__console(result[1], level='error')
            return result
        return with_logging

    def logger_msg(self, level, msg):
        """直接打印日志"""

        LEVEL = ["debug", "info", "warning", "warn",
                 "error", "fatal", "critical"]
        if level not in LEVEL:
            self.__console(f"Level {level} is not correct!", level="error")
        else:
            self.__console(msg, level=level)


if __name__ == "__main__":
    pass



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
# @File    : util_exception.py
# @Time    : 2021-12-14
# @Author  : Skypekey


class ParameterException(Exception):
    def __init__(self, errinfo) -> None:
        super().__init__()
        self.errinfo = errinfo

    def __str__(self) -> str:
        return self.errinfo


if __name__ == "__main__":
    pass
